@@ -21,7 +21,7 @@
 #define BOOM_REGRESSION_CONJUGATE_SAMPLER_HPP
 
 #include "Models/GammaModel.hpp"
-#include "Models/Glm/MvnGivenXandSigma.hpp"
+#include "Models/MvnGivenScalarSigma.hpp"
 #include "Models/Glm/RegressionModel.hpp"
 #include "Models/PosteriorSamplers/GenericGaussianVarianceSampler.hpp"
 #include "Models/PosteriorSamplers/PosteriorSampler.hpp"
@@ -33,7 +33,7 @@ namespace BOOM {
     //          p(sigsq | X) = Gamma(prior_df/2, prior_ss/2)
    public:
     RegressionConjSampler(RegressionModel *model,
-                          const Ptr<MvnGivenXandSigma> &coefficient_prior,
+                          const Ptr<MvnGivenScalarSigmaBase> &coefficient_prior,
                           const Ptr<GammaModelBase> &residual_precision_prior,
                           RNG &seeding_rng = GlobalRng::rng);
     void draw() override;
@@ -42,20 +42,21 @@ namespace BOOM {
     void find_posterior_mode(double epsilon = 1e-5) override;
     bool can_find_posterior_mode() const override { return true; }
 
-    const Vector &b0() const;
-    double kappa() const;
-    double prior_df() const;
-    double prior_ss() const;
+    double prior_df() const { return 2.0 * residual_precision_prior_->alpha(); }
+    double prior_ss() const { return 2.0 * residual_precision_prior_->beta(); }
 
    private:
-    RegressionModel *m_;
-    Ptr<MvnGivenXandSigma> mu_;
-    Ptr<GammaModelBase> siginv_;
-    Vector beta_tilde;
-    SpdMatrix ivar;
-    double SS, DF;
+    RegressionModel *model_;
+    Ptr<MvnGivenScalarSigmaBase> coefficient_prior_;
+    Ptr<GammaModelBase> residual_precision_prior_;
+    Vector posterior_mean_;
+    SpdMatrix posterior_precision_;
+    double SS_, DF_;
     GenericGaussianVarianceSampler sigsq_sampler_;
     void set_posterior_suf();
   };
+
+  typedef RegressionConjSampler RegressionConjugateSampler;
+
 }  // namespace BOOM
 #endif  // BOOM_REGRESSION_CONJUGATE_SAMPLER_HPP
