@@ -72,7 +72,9 @@ namespace BOOM {
 
   SpdMatrix::SpdMatrix(const Matrix &A, bool check) : Matrix(A) {
     if (check) {
-      double d = A.distance_from_symmetry();
+      double d;
+      uint imax, jmax;
+      std::tie(d, imax, jmax) = A.distance_from_symmetry();
       if (d > .5) {
         std::ostringstream err;
         err << "Non-symmetric matrix passed to SpdMatrix constructor."
@@ -126,7 +128,9 @@ namespace BOOM {
   }
 
   SpdMatrix &SpdMatrix::operator=(const Matrix &rhs) {
-    double d = rhs.distance_from_symmetry();
+    double d;
+    uint imax, jmax;
+    std::tie(d, imax, jmax) = rhs.distance_from_symmetry();
     if (d > .5) {
       report_error("Argument to SpdMatrix is non-symmetric.");
     }
@@ -674,6 +678,16 @@ namespace BOOM {
     return ans;
   }
 
+  SpdMatrix sandwich(const Matrix &A, const Vector &diagonal) {
+    DiagonalMatrix d(diagonal);
+    return A.Tmult(d * A);
+  }
+
+  SpdMatrix sandwich_transpose(const Matrix &A, const Vector &diagonal) {
+    Matrix tmp(A * DiagonalMatrix(diagonal));
+    return(tmp.multT(A));
+  }
+
   SpdMatrix as_symmetric(const Matrix &A) {
     assert(A.is_square());
     Matrix ans = A.transpose();
@@ -695,12 +709,12 @@ namespace BOOM {
   }
 
   Vector eigenvalues(const SpdMatrix &X) {
-    SpdEigen eigen(X, false);
+    SymmetricEigen eigen(X, false);
     return eigen.eigenvalues();
   }
 
   Vector eigen(const SpdMatrix &X, Matrix &Z) {
-    SpdEigen eigen(X, true);
+    SymmetricEigen eigen(X, true);
     Z = eigen.eigenvectors();
     return eigen.eigenvalues();
   }
