@@ -31,39 +31,28 @@ namespace BOOM {
   //============================================================
   typedef WeightedRegSuf WRS;
 
-  WRS::WeightedRegSuf(int p)
-      : xtwx_(p, 0.0), xtwy_(p, 0.0), n_(0.0), yt_w_y_(0.0), sym_(false) {}
+  WRS::WeightedRegSuf(int p) {
+    setup_mat(p);
+    clear();
+  }
 
   WRS::WeightedRegSuf(const Matrix &X, const Vector &y, const Vector &w) {
     Matrix tmpx = add_intercept(X);
     uint p = tmpx.nrow();
     setup_mat(p);
-    reweight(tmpx, y, w);
+    if (w.empty()) {
+      recompute(tmpx, y, Vector(y.size(), 1.0));
+    } else {
+      recompute(tmpx, y, w);
+    }
   }
 
-  WRS::WeightedRegSuf(const Matrix &X, const Vector &y) {
-    Matrix tmpx = add_intercept(X);
-    uint p = tmpx.nrow();
-    setup_mat(p);
-    Vector w(y.size(), 1.0);
-    reweight(tmpx, y, w);
+  WRS::WeightedRegSuf(const std::vector<Ptr<WeightedRegressionData>> &data) {
+    uint xdim = data.front()->xdim();
+    setup_mat(xdim);
+    recompute(data);
   }
 
-  WRS::WeightedRegSuf(const dsetPtr &dat) {
-    uint p = dat->front()->xdim();
-    setup_mat(p);
-    reweight(dat);
-  }
-
-  WRS::WeightedRegSuf(const WeightedRegSuf &rhs)
-      : Sufstat(rhs),
-        SufstatDetails<DataType>(rhs),
-        xtwx_(rhs.xtwx_),
-        xtwy_(rhs.xtwy_),
-        n_(rhs.n_),
-        yt_w_y_(rhs.yt_w_y_),
-        sym_(rhs.sym_) {}
-
   WRS *WRS::clone() const { return new WRS(*this); }
 
   std::ostream &WRS::print(std::ostream &out) const {
@@ -72,6 +61,7 @@ namespace BOOM {
         << "xtwy_   = " << xtwy_ << endl
         << "n_      = " << n_ << endl
         << "yt_w_y_ = " << yt_w_y_ << endl
+        << "sumw_   = " << sumw_ << endl
         << "sumlogw_= " << sumlogw_ << endl;
     return out;
   }
@@ -81,6 +71,7 @@ namespace BOOM {
     xtwy_ += s->xtwy_;
     n_ += s->n_;
     yt_w_y_ += s->yt_w_y_;
+    sumw_ += s->sumw_;
     sumlogw_ += s->sumlogw_;
     sym_ = sym_ && s->sym_;
   }
@@ -90,6 +81,7 @@ namespace BOOM {
     xtwy_ += s.xtwy_;
     n_ += s.n_;
     yt_w_y_ += s.yt_w_y_;
+    sumw_ += s.sumw_;
     sumlogw_ += s.sumlogw_;
     sym_ = sym_ && s.sym_;
   }
@@ -103,6 +95,7 @@ namespace BOOM {
     ans.concat(xtwy_);
     ans.push_back(n_);
     ans.push_back(yt_w_y_);
+    ans.push_back(sumw_);
     ans.push_back(sumlogw_);
     return ans;
   }
@@ -116,6 +109,8 @@ namespace BOOM {
     ++v;
     yt_w_y_ = *v;
     ++v;
+    sumw_ = *v;
+    ++v;
     sumlogw_ = *v;
     ++v;
     return v;
@@ -133,16 +128,16 @@ namespace BOOM {
     sym_ = false;
   }
 
-  void WRS::reweight(const Matrix &X, const Vector &y, const Vector &w) {
+  void WRS::recompute(const Matrix &X, const Vector &y, const Vector &w) {
     uint n = w.size();
     assert(y.size() == n && X.nrow() == n);
     clear();
     for (uint i = 0; i < n; ++i) add_data(X.row(i), y[i], w[i]);
   }
 
-  void WRS::reweight(const dsetPtr &dp) {
+  void WRS::recompute(const std::vector<Ptr<WeightedRegressionData>> &data) {
     clear();
-    for (uint i = 0; i < dp->size(); ++i) update((*dp)[i]);
+    for (uint i = 0; i < data.size(); ++i) update(data[i]);
   }
 
   //------------------------------------------------------------
@@ -150,11 +145,23 @@ namespace BOOM {
 
   void WRS::set_xtwy(const Vector &xtwy) { xtwy_ = xtwy; }
 
+  void WRS::reset(const SpdMatrix &xtwx, const Vector &xtwy, double ytwy,
+                  double sample_size, double sum_weights, double sum_log_weights) {
+    xtwx_ = xtwx;
+    xtwy_ = xtwy;
+    n_ = sample_size;
+    yt_w_y_ = ytwy;
+    sumw_ = sum_weights;
+    sumlogw_ = sum_log_weights;
+    sym_ = true;
+  }
+  
   //------------------------------------------------------------
 
   void WRS::add_data(const Vector &x, double y, double w) {
     ++n_;
     yt_w_y_ += w * y * y;
+    sumw_ += w;
     sumlogw_ += log(w);
     xtwx_.add_outer(x, w, false);
     xtwy_.axpy(x, w * y);
@@ -164,7 +171,7 @@ namespace BOOM {
   void WRS::clear() {
     xtwx_ = 0.0;
     xtwy_ = 0.0;
-    yt_w_y_ = n_ = sumlogw_ = 0.0;
+    sumw_ = yt_w_y_ = n_ = sumlogw_ = 0.0;
     sym_ = false;
   }
 
@@ -199,7 +206,7 @@ namespace BOOM {
 
   double WRS::SST() const { return yty() / sumw() - pow(ybar(), 2); }
   double WRS::n() const { return n_; }
-  double WRS::sumw() const { return xtwx_(0, 0); }
+  double WRS::sumw() const { return sumw_;}
   double WRS::sumlogw() const { return sumlogw_; }
   double WRS::ybar() const { return xtwy_[0] / sumw(); }
 
