@@ -20,12 +20,11 @@
 #include <vector>
 
 namespace BOOM {
-  using namespace std;
-  using std::string;
-  vector<string> read_file(istream &in) {
-    vector<string> ans;
+
+  std::vector<std::string> read_file(std::istream &in) {
+    std::vector<std::string> ans;
     while (in) {
-      string line;
+      std::string line;
       getline(in, line);
       if (!in) break;
       ans.push_back(line);
@@ -33,8 +32,8 @@ namespace BOOM {
     return ans;
   }
 
-  vector<string> read_file(const string &fname) {
-    ifstream in(fname.c_str());
+  std::vector<std::string> read_file(const std::string &fname) {
+    std::ifstream in(fname.c_str());
     return read_file(in);
   }
 }  // namespace BOOM
